%
% zero-dimensional energy balance model
%
% define constants
%
S0 = 1370; % in W/m^2
cp = 2.08E+08; % in J/m^2 dec C
dt0 = 1;  % in years
dt = dt0*365.25*24*3600; % in seconds
%
% calculate relaxation 
%
% set parameters
%
% default albedo
A0 = 0.3;
%
% we use linearized form of the energy balance
% Cp dT/dt = (1-A0)*S/4 - sigma T^4
%
% choose graybody parameter approx:
% sigma T^4 = A + B (T-T0)
% where T0=0C.
% A = 221.3 W/m^2, B=1.25 W/m^2K gives mid-range sensitivity and realistic
% global mean temperature
%
A = 221.3; % in W/m^2
B = 1.25; % in W/m^2 dec C
%
% define climate sensitivity as temperature increase corresponding to 2 x
% CO2 (4 W/m^2) forcing
sens = 5.35*log(2)/B;
% calculate relaxation time constant
taus = cp/B;  % in seconds
tau = taus/(365.25*24*3600); % in years
%
%
% set amplitude of internal variability component of global temperature
% 0.73 GIVES 65% FORCED/35% NOISE, CONSISTENT w/ CROWLEY (2000)
%
ampfactor = 0.73;
% set ampfactor=0 for no noise case
%ampfactor=0.0;
%
% prescribe number of random realizations
nrealize=1000;
%
% set parameters for proxy temperature data
% PREFERRED VALUE 0.32, AS COMPUTED FOR ACTUAL MULTIPROXY NETWORKS BY MANN
% ET AL (2007) JGR
rho=0.32;
%
% set amplitude of noise component of proxy temperature series
% PREFERRED VALUE 0.345 (for ampfactor= 0.73) GIVES 40% SIGNAL/60% NOISE, roughly consistent
% w/ cross-validation results for millennial Mann et al '08 CPS
% reconstruction back to AD 800
ampproxynoise = 0.345;
%
%
% read in long-term forcing
load co2.dat
year=co2(:,1);
cotwo=co2(:,2);
CO20 = 280.0;
% scale up to get CO2equiv ghg forcing from CO2 only 
cotwoequiv=CO20+1.75*(cotwo-CO20);
forcingcotwo= 5.35 * log(cotwoequiv/CO20);
% uses Ammann volcanic forcing, but the controversial 1258 eruption was been decreased by factor 1/3
% relative to its nominal value owing to its outlier behavior and poor support in observations (e.g.
% tree-ring records, which don't show any obvious cooling at this time).
% support in tree-ring data
load volcanic.dat
volc=volcanic(:,2);
load solarforcing.dat
solardiff=solarforcing(:,2);
% scale up by 0.65/0.25 to get higher of the two Ammann et al solar forcing
% estimates
solardiff=(0.65/0.25)*solardiff;
solar = S0+solardiff;
load aerosol.dat
aer(1021:1150)=aerosol(:,2);
aer=aer';
% can choose to zero out anthropogenic forcing
%aer(1:1150)=0.0;
%forcingcotwo(1:1150)=0.0;
% total forcing anomaly
longwave = forcingcotwo;
shortwave=aer+volc+(1-A0)*solar/4;
%
% impose the combined shortwave + longwave forcing as an effective increase in downward shortwave
% radiation
forcingrad = shortwave+longwave;
forcestd = std(forcingrad);
stochamp = ampfactor*forcestd;
% define initial temperature as equilibrium for initial instantaneous
% forcing
%
ntot = length(forcingrad);
% alternatively, use constant forcing (comment this out if not using)
%forcingrad(1:ntot)=forcingrad(1);
%
%
% generate noise realizations
for j=1:nrealize
for i=1:ntot
    nois(i)=stochamp*gasdev;
end
noise=nois';
% now integrate forward
%
surftemp0 = (forcingrad(1)-A)/B;
Told=surftemp0;
forcingtot=forcingrad+noise;
snr(j)=std(forcingrad)/std(noise);
pctnoise(j)=var(noise)/var(forcingtot);
for i=1:ntot
    Tnew = Told + (1/cp)*(forcingtot(i)-A-B*Told)*dt;
    %
    surftemp(i)=Tnew;
    Told=Tnew;
end
surftemp=surftemp';
    hd=plot(year,surftemp);
    set(hd,'color',[.86 .86 .86])
temprecord(1:ntot,j)=surftemp;
surftemppre=surftemp(1:1000);
surftempinstr=surftemp(1001:ntot);
% need to subtract off mean before estimating H
surftemp0=surftemp-mean(surftemp);
surftemppre0=surftemppre-mean(surftemppre);
surftempinstr0=surftempinstr-mean(surftempinstr);
%
% calculate hurst coefficient H of resulting time series during entire,
% pre-anthropogenic, and anthropogenic-only
HEST1 = Hest(surftemp0);
HEST2 = Hest(surftemppre0);
HEST3 = Hest(surftempinstr0);
h1(j)=HEST1;
h2(j)=HEST2;
h3(j)=HEST3;
%
% now include effect of additive proxy noise with rho=0.32
%
[noiseprx] = rednoise(ntot,rho)';
proxynoise=ampproxynoise*noiseprx;
proxyrecord(:,j)=temprecord(:,j)+proxynoise;
[proxysmoothed(:,j),w0,w1,w2,msebest] = lowpassadaptive(proxyrecord(:,j),0.05);

snrprox(j)=std(temprecord(:,j))/std(proxynoise);
pctnoiseprox(j)=var(proxynoise)/var(proxyrecord(:,j));
%
% calculate hurst coefficients for proxy-noise added temperature records
% Use effective spacing of independent samples for decadal records
nspace = 10;
%
proxydec = decimate(proxyrecord(:,j),nspace);
proxydecpre = decimate(proxyrecord(1:1000,j),nspace);
% need to subtract off mean before estimating H
proxydec0=proxydec-mean(proxydec);
proxydecpre0 = proxydecpre-mean(proxydecpre);
HEST1prx = Hest(proxydec0);
HEST2prx = Hest(proxydecpre0);
h1prx(j)=HEST1prx;
h2prx(j)=HEST2prx;
%
%
end
%
% tabulate H statistics for noise-free temperature records
%
h1sort=sort(h1);
h2sort=sort(h2);
h3sort=sort(h3);
lower1=h1sort(5*nrealize/100);
med1=h1sort(50*nrealize/100);
upper1=h1sort(95*nrealize/100);
lower2=h2sort(5*nrealize/100);
med2=h2sort(50*nrealize/100);
upper2=h2sort(95*nrealize/100);
lower3=h3sort(5*nrealize/100);
med3=h3sort(50*nrealize/100);
upper3=h3sort(95*nrealize/100);
%
%
% tabulate H statistics for proxy-noise added temperature records
%
%
h1sortprx=sort(h1prx);
h2sortprx=sort(h2prx);
lower1prx=h1sortprx(5*nrealize/100);
med1prx=h1sortprx(50*nrealize/100);
upper1prx=h1sortprx(95*nrealize/100);
lower2prx=h2sortprx(5*nrealize/100);
med2prx=h2sortprx(50*nrealize/100);
upper2prx=h2sortprx(95*nrealize/100);
%
%
% now calculate H for observational global mean surface temperature record
% 1850-1999
%
load hadcrut3gl.dat
globe=hadcrut3gl(1:150,14);
% need to subtract off mean before estimating H
globe0=globe-mean(globe);
[globesmoothed,w0,w1,w2,msebest] = lowpassadaptive(globe,0.10);
yearglobe=year(1001:1150);
modernmean=mean(temprecord(1001:1150,j));
longtermmean=mean(temprecord(:,j));
globeadjust=globe+modernmean-mean(globe);
globesmoothedadjust=globesmoothed+modernmean-mean(globesmoothed);
HESTobs = Hest(globe0);
%
% now calculate H for Mann et al '08 (CPS) proxy surface temperature
% reconstruction AD 850-1996
%
% owing to decadal resolution, need to sample at 10 year spacing 
%
load nhcru_cps_composite
nhem_cps=compos';
cps = nhem_cps(850:1996);
cpsmerged=cps;
cpsmerged(1001:1150)=globe;
[cpssmoothed,w0,w1,w2,msebest] = lowpassadaptive(cpsmerged,0.10);
cpssmoothedadjust = cpssmoothed+longtermmean-mean(cpssmoothed);
cpspreinstr = cps(1:1000);
cpsdec = decimate(cps,nspace);
cpspreinstrdec = decimate(cpspreinstr,nspace);
% need to subtract off mean before estimating H
cpspreinstrdec0=cpspreinstrdec-mean(cpspreinstrdec);
cpsdec0=cpsdec-mean(cpsdec);
HEST_CPSpreinstr = Hest(cpspreinstrdec0);
HEST_CPSfull = Hest(cpsdec0);
%







      